==> krb4-0.0.tar.gz: krb4-0.0/src/acconfig.h <==
/*  Define this if RETSIGTYPE == void  */
#undef VOID_RETSIGTYPE

/*  Define this if struct utmp have ut_host  */
#undef HAVE_UT_HOST

@BOTTOM@


/*
 * Set ORGANIZATION to be the desired organization string printed
 * by the 'kinit' program.  It may have spaces.
 */
#define ORGANIZATION "eBones International"

#if 0
#define KRB_CNF_FILES	{ "/etc/krb.conf",   "/etc/kerberosIV/krb.conf", 0}
#define KRB_RLM_FILES	{ "/etc/krb.realms", "/etc/kerberosIV/krb.realms", 0}
#define KRB_EQUIV	"/etc/krb.equiv"

#define KEYFILE		"/etc/srvtab"

#define MKEYFILE	"/.k"
#define DBM_FILE	"/var/kerberos/principal"
#define DEFAULT_ACL_DIR	"/var/kerberos"

#define KRBLOG		"/var/log/kerberos.log"	/* master server  */
#define KRBSLAVELOG	"/var/log/kerberos_slave.log" /* slave server  */
#define KADM_SYSLOG	"/var/log/admin_server.syslog"
#define K_LOGFIL	"/var/log/kpropd.log"
#endif

/* Maximum values on all known systems */
#define MaxHostNameLen (64+4)
#define MaxPathLen (1024+4)

/*
 * Define NDBM if you are using the 4.3 ndbm library (which is part of
 * libc).  If not defined, 4.2 dbm will be assumed.
 */
#define NDBM

/*
 * Atleast HPUX does not have setreuid and seteuid
 */

#ifndef HAVE_SETREUID
#ifdef HAVE_SETRESUID
#define setreuid(r, e) setresuid((r), (e), -1)
#else
#define setreuid(r, e) k_setreuid((r), (e))
#endif
#endif

#ifndef HAVE_SETEUID
#ifdef HAVE_SETRESUID
#define seteuid(e) setresuid(-1, (e), -1)
#elif defined(HAVE_SETREUID)
#define seteuid(e) setreuid(-1, (e))
#else
/* this might be:
#define seteuid(e) 0
*/
#error There is no way to set e-uid! (seteuid, setreuid, setresuid)
#endif
#endif

/*
 * AIX braindamage!
 */
#if _AIX
#define _ALL_SOURCE
#endif

==> krb4-0.1.tar.gz: krb4-0.1/src/acconfig.h <==
/*  Define this if RETSIGTYPE == void  */
#undef VOID_RETSIGTYPE

/*  Define this if struct utmp have ut_host  */
#undef HAVE_UT_HOST

@BOTTOM@


/*
 * Set ORGANIZATION to be the desired organization string printed
 * by the 'kinit' program.  It may have spaces.
 */
#define ORGANIZATION "eBones International"

#if 0
#define KRB_CNF_FILES	{ "/etc/krb.conf",   "/etc/kerberosIV/krb.conf", 0}
#define KRB_RLM_FILES	{ "/etc/krb.realms", "/etc/kerberosIV/krb.realms", 0}
#define KRB_EQUIV	"/etc/krb.equiv"

#define KEYFILE		"/etc/srvtab"

#define MKEYFILE	"/.k"
#define DBM_FILE	"/var/kerberos/principal"
#define DEFAULT_ACL_DIR	"/var/kerberos"

#define KRBLOG		"/var/log/kerberos.log"	/* master server  */
#define KRBSLAVELOG	"/var/log/kerberos_slave.log" /* slave server  */
#define KADM_SYSLOG	"/var/log/admin_server.syslog"
#define K_LOGFIL	"/var/log/kpropd.log"
#endif

/* Maximum values on all known systems */
#define MaxHostNameLen (64+4)
#define MaxPathLen (1024+4)

/*
 * Define NDBM if you are using the 4.3 ndbm library (which is part of
 * libc).  If not defined, 4.2 dbm will be assumed.
 */
/* We are always using the NDBM API. */
#define NDBM

/*
 * Define HAVE_NEW_DB if database is in a .db file rather than in .dir
 * and .pag files.
 */
/* This is a really BAD way of testing this, yuk! */
#if defined(__FreeBSD__) || defined(__NetBSD__)
#define HAVE_NEW_DB
#endif

/*
 * Atleast HPUX does not have setreuid and seteuid
 */

#ifndef HAVE_SETREUID
#ifdef HAVE_SETRESUID
#define setreuid(r, e) setresuid((r), (e), -1)
#else
#define setreuid(r, e) k_setreuid((r), (e))
#endif
#endif

#ifndef HAVE_SETEUID
#ifdef HAVE_SETRESUID
#define seteuid(e) setresuid(-1, (e), -1)
#elif defined(HAVE_SETREUID)
#define seteuid(e) setreuid(-1, (e))
#else
/* this might be:
#define seteuid(e) 0
*/
#error There is no way to set e-uid! (seteuid, setreuid, setresuid)
#endif
#endif

/*
 * AIX braindamage!
 */
#if _AIX
#define _ALL_SOURCE
#endif
